import React, { useState, useEffect } from 'react';
import { api_url } from '../env';  
import "../styleing/body.css";
import Pagination from './Pagination';


import AddPostForm from './addPost';

function Body() { 
  const [data, setData] = useState([]);
  const [error, setError] = useState(null); 
  const [filteredData, setFilteredData] = useState([]);
  const [currentPage,setCurrentPage] = useState(1);
  const postsPerPage = 6;
  const fetchData = async () => {
    try {
      const res = await fetch(api_url);
      const d = await res?.json();
      setData(d);
      setFilteredData(d)
    } catch (e) {
      setError(e);
    }
  };

  useEffect(() => {
    fetchData();
  }, []);

  const handleAddPost = (newPost) => {
    const postWithId = { ...newPost, id: Date.now() }; 
    const updatedData = [postWithId,...data];
    setData(updatedData);
    setFilteredData(updatedData); 
  };
  const handleDeletePost = (id) => {
    const updatedData = data?.filter((post) => post?.id !== id);
    setData(updatedData);
    setFilteredData(updatedData);
  };
  
  const indexOfLastPost = currentPage * postsPerPage;
  const indexOfFirstPost = indexOfLastPost-postsPerPage;
  const currentPosts = filteredData.slice(indexOfFirstPost,indexOfLastPost);
  const totalPages = Math.ceil(filteredData?.length/postsPerPage);

  if (error) {
    return <div>Error: {error.message}</div>;  
  }

  return (
    <div className="App">
        <ul>

          {currentPosts.map((post) => (
            <li key={post?.id}>
            
              <h1> Title :{post?.title}</h1>
              <p> <b>Content :</b>{post?.body}</p>
              <button onClick={() => handleDeletePost(post?.id)}>Delete</button>
            </li>
          ))}
        </ul>
        <AddPostForm onAddPost={handleAddPost} />
        <Pagination
        currentPage={currentPage}
        totalPages={totalPages}
        onPageChange={(page)=>setCurrentPage(page)}></Pagination>
    </div>
  );
}

export default Body;
